[patch 43/44] ntfs: remove generic_ffs()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Now the only user who are using generic_ffs() is ntfs filesystem.
This patch isolates generic_ffs() as ntfs_ffs() for ntfs.

Signed-off-by: Akinobu Mita <[email protected]>

 fs/ntfs/logfile.c |    4 ++--
 fs/ntfs/mft.c     |    2 +-
 fs/ntfs/ntfs.h    |   29 +++++++++++++++++++++++++++++
 3 files changed, 32 insertions(+), 3 deletions(-)

Index: 2.6-git/fs/ntfs/mft.c
===================================================================
--- 2.6-git.orig/fs/ntfs/mft.c
+++ 2.6-git/fs/ntfs/mft.c
@@ -2672,7 +2672,7 @@ mft_rec_already_initialized:
 			ni->name_len = 4;
 
 			ni->itype.index.block_size = 4096;
-			ni->itype.index.block_size_bits = generic_ffs(4096) - 1;
+			ni->itype.index.block_size_bits = ntfs_ffs(4096) - 1;
 			ni->itype.index.collation_rule = COLLATION_FILE_NAME;
 			if (vol->cluster_size <= ni->itype.index.block_size) {
 				ni->itype.index.vcn_size = vol->cluster_size;
Index: 2.6-git/fs/ntfs/ntfs.h
===================================================================
--- 2.6-git.orig/fs/ntfs/ntfs.h
+++ 2.6-git/fs/ntfs/ntfs.h
@@ -132,4 +132,33 @@ extern int ntfs_ucstonls(const ntfs_volu
 /* From fs/ntfs/upcase.c */
 extern ntfschar *generate_default_upcase(void);
 
+static inline int ntfs_ffs(int x)
+{
+	int r = 1;
+
+	if (!x)
+		return 0;
+	if (!(x & 0xffff)) {
+		x >>= 16;
+		r += 16;
+	}
+	if (!(x & 0xff)) {
+		x >>= 8;
+		r += 8;
+	}
+	if (!(x & 0xf)) {
+		x >>= 4;
+		r += 4;
+	}
+	if (!(x & 3)) {
+		x >>= 2;
+		r += 2;
+	}
+	if (!(x & 1)) {
+		x >>= 1;
+		r += 1;
+	}
+	return r;
+}
+
 #endif /* _LINUX_NTFS_H */

Index: 2.6-git/fs/ntfs/logfile.c
===================================================================
--- 2.6-git.orig/fs/ntfs/logfile.c
+++ 2.6-git/fs/ntfs/logfile.c
@@ -515,10 +515,10 @@ BOOL ntfs_check_logfile(struct inode *lo
 		log_page_size = PAGE_CACHE_SIZE;
 	log_page_mask = log_page_size - 1;
 	/*
 	 * Use generic_ffs() instead of ffs() to enable the compiler to
 	 * optimize log_page_size and log_page_bits into constants.
 	 */
-	log_page_bits = generic_ffs(log_page_size) - 1;
+	log_page_bits = ntfs_ffs(log_page_size) - 1;
 	size &= ~(s64)(log_page_size - 1);
 	/*
 	 * Ensure the log file is big enough to store at least the two restart
@@ -515,10 +515,10 @@ BOOL ntfs_check_logfile(struct inode *lo
 	log_page_mask = log_page_size - 1;
 	/*
-	 * Use generic_ffs() instead of ffs() to enable the compiler to
+	 * Use ntfs_ffs() instead of ffs() to enable the compiler to
 	 * optimize log_page_size and log_page_bits into constants.
 	 */
--
-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

[Index of Archives]     [Kernel Newbies]     [Netfilter]     [Bugtraq]     [Photo]     [Stuff]     [Gimp]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Video 4 Linux]     [Linux for the blind]     [Linux Resources]
  Powered by Linux